What's inside:
--------------

1.4.0 (17/08/2021)
------------------
*   Added support for Translation into multiple languages.
*   Can query out list of supporting translation languages.
*   Fixed some bugs arising due to change in source page structure.

1.3.0 (01/08/2021)
------------------
*   Added new functions for searching Examples, Synonyms and Antonyms.

1.1.2 (31/07/2021)
------------------
*   Fixed some typo errors in code.

1.1.0 (30/07/2021)
------------------
*   Minor changes in code logic.

1.0.1 (29/07/2021)
------------------
*   First stable build with MeaningsFinder class for finding definations.
